@@ -1,24 +1,5 @@
-/* Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2021 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include <Python.h>
 #include <structmember.h> /* required for PyMemberDef */
@@ -62,7 +43,11 @@ static constexpr AirspaceClassStringCouple airspace_class_strings[] = {
   { "RMZ", RMZ },
 };
 
-PyObject* xcsoar_Airspaces_new(PyTypeObject *type, PyObject *args, PyObject *kwargs) {
+PyObject *
+xcsoar_Airspaces_new(PyTypeObject *type,
+                     [[maybe_unused]] PyObject *args,
+                     [[maybe_unused]] PyObject *kwargs)
+{
   /* constructor */
   Pyxcsoar_Airspaces *self;
   self = (Pyxcsoar_Airspaces *)type->tp_alloc(type, 0);
@@ -189,7 +174,7 @@ PyObject* xcsoar_Airspaces_addPolygon(Pyxcsoar_Airspaces *self, PyObject *args)
 
   /* Create airspace and save it into the database */
   auto as = std::make_shared<AirspacePolygon>(points);
-  as->SetProperties(std::move(name), type, base, top);
+  as->SetProperties(std::move(name), type, {}, base, top);
   self->airspace_database->Add(std::move(as));
 
   Py_RETURN_NONE;
