@@ -15,7 +15,7 @@ ConditionMonitorAATTime::CheckCondition([[maybe_unused]] const NMEAInfo &basic,
       calculated.common_stats.task_type != TaskType::ORDERED ||
       !calculated.ordered_task_stats.task_valid ||
       !calculated.ordered_task_stats.has_targets ||
-      !calculated.ordered_task_stats.start.task_started ||
+      !calculated.ordered_task_stats.start.HasStarted() ||
       !calculated.common_stats.active_has_next ||
       calculated.ordered_task_stats.task_finished)
     return false;
