@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2021 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "BufferedPort.hpp"
 #include "Device/Error.hpp"
@@ -61,17 +41,18 @@ BufferedPort::StartRxThread()
 }
 
 std::size_t
-BufferedPort::Read(void *dest, std::size_t length)
+BufferedPort::Read(std::span<std::byte> dest)
 {
   assert(!running);
 
   const std::lock_guard lock{mutex};
 
   auto r = buffer.Read();
-  std::size_t nbytes = std::min(length, r.size());
-  std::copy_n(r.begin(), nbytes, (std::byte *)dest);
-  buffer.Consume(nbytes);
-  return nbytes;
+  if (r.size() > dest.size())
+    r = r.first(dest.size());
+  std::copy(r.begin(), r.end(), dest.data());
+  buffer.Consume(r.size());
+  return r.size();
 }
 
 void
