@@ -30,10 +30,15 @@
 #include "Widget/VScrollWidget.hpp"
 #include "Interface.hpp"
 #include "Language/Language.hpp"
+#include "BackendComponents.hpp"
+#include "DataComponents.hpp"
 
-TaskManagerDialog::TaskManagerDialog(WndForm &_dialog) noexcept
+inline
+TaskManagerDialog::TaskManagerDialog(WndForm &_dialog,
+                                     std::unique_ptr<OrderedTask> &&_task) noexcept
     :TabWidget(Orientation::AUTO),
-     dialog(_dialog) {}
+     dialog(_dialog),
+     task(std::move(_task)) {}
 
 TaskManagerDialog::~TaskManagerDialog() noexcept = default;
 
@@ -75,7 +80,10 @@ void
 TaskManagerDialog::Initialise(ContainerWindow &parent,
                               const PixelRect &rc) noexcept
 {
-  task = protected_task_manager->TaskClone();
+  if (!task) {
+    task = backend_components->protected_task_manager->TaskClone();
+    modified = false;
+  }
 
   /* create the controls */
 
@@ -181,14 +189,14 @@ TaskManagerDialog::Commit()
     { // this must be done in thread lock because it potentially changes the
       // waypoints database
       ScopeSuspendAllThreads suspend;
-      task->CheckDuplicateWaypoints(way_points);
-      way_points.Optimise();
+      task->CheckDuplicateWaypoints(*data_components->waypoints);
+      data_components->waypoints->Optimise();
     }
 
-    protected_task_manager->TaskCommit(*task);
+    backend_components->protected_task_manager->TaskCommit(*task);
 
     try {
-      protected_task_manager->TaskSaveDefault();
+      backend_components->protected_task_manager->TaskSaveDefault();
     } catch (...) {
       ShowError(std::current_exception(), _("Failed to save file."));
       return false;
@@ -209,7 +217,7 @@ void
 TaskManagerDialog::Revert()
 {
   // create new task first to guarantee pointers are different
-  task = protected_task_manager->TaskClone();
+  task = backend_components->protected_task_manager->TaskClone();
   /**
    * \todo Having local pointers scattered about is an accident waiting to
    *       happen. Need a semantic that provides the authoritative pointer to
@@ -225,15 +233,21 @@ TaskManagerDialog::Revert()
 }
 
 void
-dlgTaskManagerShowModal()
+dlgTaskManagerShowModal(std::unique_ptr<OrderedTask> task)
 {
-  if (protected_task_manager == nullptr)
+  if (!backend_components->protected_task_manager)
     return;
 
   const DialogLook &look = UIGlobals::GetDialogLook();
   TWidgetDialog<TaskManagerDialog>
     dialog(WidgetDialog::Full{}, UIGlobals::GetMainWindow(),
            look, _("Task Manager"));
-  dialog.SetWidget(dialog);
+  dialog.SetWidget(dialog, std::move(task));
   dialog.ShowModal();
 }
+
+void
+dlgTaskManagerShowModal()
+{
+  dlgTaskManagerShowModal({});
+}
