@@ -31,7 +31,8 @@
 class FlarmTrafficControl : public FlarmTrafficWindow {
 protected:
   bool enable_auto_zoom = true, dragging = false;
-  unsigned zoom = 2;
+  unsigned zoom = 3;
+  static constexpr unsigned num_zoom_options = 5;
   Angle task_direction = Angle::Degrees(-1);
   GestureManager gestures;
 
@@ -76,7 +77,7 @@ public:
   }
 
   bool CanZoomOut() const {
-    return zoom < 4;
+    return zoom < num_zoom_options;
   }
 
   bool CanZoomIn() const {
@@ -139,14 +140,16 @@ FlarmTrafficControl::GetZoomDistance(unsigned zoom)
 {
   switch (zoom) {
   case 0:
-    return 500;
+    return 100;
   case 1:
-    return 1000;
-  case 3:
-    return 5000;
-  case 4:
-    return 10000;
+    return 500;
   case 2:
+    return 1000;
+  case 4:
+    return 5000;
+  case 5:
+    return 10000;
+  case 3:
   default:
     return 2000;
   }
@@ -185,8 +188,8 @@ FlarmTrafficControl::CalcAutoZoom()
   }
 
   double zoom_dist2 = zoom_dist;
-  for (unsigned i = 0; i <= 4; i++) {
-    if (i == 4 || GetZoomDistance(i) >= zoom_dist2) {
+  for (unsigned i = 0; i <= num_zoom_options; i++) {
+    if (i == num_zoom_options || GetZoomDistance(i) >= zoom_dist2) {
       SetZoom(i);
       break;
     }
@@ -221,7 +224,7 @@ FlarmTrafficControl::ZoomOut()
   if (WarningMode())
     return;
 
-  if (zoom < 4)
+  if (zoom < num_zoom_options)
     SetZoom(zoom + 1);
 
   SetAutoZoom(false);
@@ -257,13 +260,13 @@ FlarmTrafficControl::PaintTaskDirection(Canvas &canvas) const
 
   BulkPixelPoint triangle[3];
   triangle[0].x = 0;
-  triangle[0].y = -radius / Layout::FastScale(1) + 15;
+  triangle[0].y = -(int)radar_renderer.GetRadius() / Layout::FastScale(1) + 15;
   triangle[1].x = 7;
   triangle[1].y = triangle[0].y + 30;
   triangle[2].x = -triangle[1].x;
   triangle[2].y = triangle[1].y;
 
-  PolygonRotateShift(triangle, radar_mid,
+  PolygonRotateShift(triangle, radar_renderer.GetCenter(),
                      task_direction - (enable_north_up ?
                                        Angle::Zero() : heading),
                      Layout::FastScale(100u));
@@ -282,9 +285,8 @@ FlarmTrafficControl::PaintClimbRate(Canvas &canvas, PixelRect rc,
   canvas.DrawText(rc.GetTopRight().At(-(int)label_width, 0), _("Vario"));
 
   // Format climb rate
-  TCHAR buffer[20];
   Unit unit = Units::GetUserVerticalSpeedUnit();
-  FormatUserVerticalSpeed(climb_rate, buffer, false);
+  const auto buffer = FormatUserVerticalSpeed(climb_rate, false);
 
   // Calculate unit size
   canvas.Select(look.info_units_font);
@@ -297,7 +299,7 @@ FlarmTrafficControl::PaintClimbRate(Canvas &canvas, PixelRect rc,
   // Calculate value size
   canvas.Select(look.info_values_font);
   const unsigned value_height = look.info_values_font.GetAscentHeight();
-  const unsigned value_width = canvas.CalcTextSize(buffer).width;
+  const unsigned value_width = canvas.CalcTextSize(buffer.c_str()).width;
 
   // Calculate positions
   const int max_height = std::max(unit_height, value_height);
@@ -310,7 +312,7 @@ FlarmTrafficControl::PaintClimbRate(Canvas &canvas, PixelRect rc,
   const int value_y = y - value_height;
 
   // Paint value
-  canvas.DrawText({value_x, value_y}, buffer);
+  canvas.DrawText({value_x, value_y}, buffer.c_str());
 
   // Paint unit
   canvas.Select(look.info_units_font);
