@@ -1,25 +1,5 @@
-/*
-Copyright_License {
-
-  XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2021 The XCSoar Project
-  A detailed list of copyright holders can be found in the file "AUTHORS".
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-}
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The XCSoar Project
 
 #include "RotateDisplay.hpp"
 #include "DisplayOrientation.hpp"
@@ -102,23 +82,63 @@ Display::Rotate(DisplayOrientation orientation)
                                               android_orientation);
 #elif defined(KOBO)
   const char *rotate = "3";
+  KoboModel kobo_model = DetectKoboModel();
 
   switch (orientation) {
   case DisplayOrientation::DEFAULT:
   case DisplayOrientation::PORTRAIT:
-    rotate = DetectKoboModel() == KoboModel::LIBRA2 ? "1" : "3";
+    switch(kobo_model) {
+    case KoboModel::LIBRA2:
+      rotate = "1";
+      break;
+    case KoboModel::LIBRA_H2O:
+      rotate = "0";
+      break;
+    default:
+      rotate = "3";
+      break;
+    }
     break;
-
   case DisplayOrientation::REVERSE_PORTRAIT:
-    rotate = DetectKoboModel() == KoboModel::LIBRA2 ? "3" : "1";
+    switch(kobo_model) {
+    case KoboModel::LIBRA2:
+      rotate = "3";
+      break;
+    case KoboModel::LIBRA_H2O:
+      rotate = "2";
+      break;
+    default:
+      rotate = "1";
+      break;
+    }
     break;
 
   case DisplayOrientation::LANDSCAPE:
-    rotate = DetectKoboModel() == KoboModel::LIBRA2 ? "2" : "0";
+    switch(kobo_model) {
+    case KoboModel::LIBRA2:
+      rotate = "2";
+      break;
+    case KoboModel::LIBRA_H2O:
+      rotate = "1";
+      break;
+    default:
+      rotate = "0";
+      break;
+    }
     break;
 
   case DisplayOrientation::REVERSE_LANDSCAPE:
-    rotate = DetectKoboModel() == KoboModel::LIBRA2 ? "0" : "2";
+    switch(kobo_model) {
+    case KoboModel::LIBRA2:
+      rotate = "0";
+      break;
+    case KoboModel::LIBRA_H2O:
+      rotate = "3";
+      break;
+    default:
+      rotate = "2";
+      break;
+    }
     break;
   };
 
