@@ -8,7 +8,6 @@
 #include "util/StringAPI.hxx"
 #include "util/StringCompare.hxx"
 #include "util/StringPointer.hxx"
-#include "util/Macros.hpp"
 
 #ifdef _UNICODE
 #include "util/AllocatedString.hxx"
@@ -17,10 +16,10 @@
 #include <windef.h> /* for MAX_PATH */
 
 AllocatedPath
-ProfileMap::GetPath(const char *key) const noexcept
+ProfileMap::GetPath(std::string_view key) const noexcept
 {
   TCHAR buffer[MAX_PATH];
-  if (!Get(key, buffer, ARRAY_SIZE(buffer)))
+  if (!Get(key, std::span{buffer}))
       return nullptr;
 
   if (StringIsEmpty(buffer))
@@ -30,7 +29,7 @@ ProfileMap::GetPath(const char *key) const noexcept
 }
 
 bool
-ProfileMap::GetPathIsEqual(const char *key, Path value) const noexcept
+ProfileMap::GetPathIsEqual(std::string_view key, Path value) const noexcept
 {
   const auto saved_value = GetPath(key);
   if (saved_value == nullptr)
@@ -55,10 +54,10 @@ BackslashBaseName(const TCHAR *p) noexcept
 #ifdef _UNICODE
 
 BasicAllocatedString<TCHAR>
-ProfileMap::GetPathBase(const char *key) const noexcept
+ProfileMap::GetPathBase(std::string_view key) const noexcept
 {
   TCHAR buffer[MAX_PATH];
-  if (!Get(key, buffer, ARRAY_SIZE(buffer)))
+  if (!Get(key, std::span{buffer}))
       return nullptr;
 
   const TCHAR *base = BackslashBaseName(buffer).c_str();
@@ -71,7 +70,7 @@ ProfileMap::GetPathBase(const char *key) const noexcept
 #else
 
 StringPointer<TCHAR>
-ProfileMap::GetPathBase(const char *key) const noexcept
+ProfileMap::GetPathBase(std::string_view key) const noexcept
 {
   const auto *path = Get(key);
   if (path != nullptr)
@@ -83,7 +82,7 @@ ProfileMap::GetPathBase(const char *key) const noexcept
 #endif
 
 void
-ProfileMap::SetPath(const char *key, Path value) noexcept
+ProfileMap::SetPath(std::string_view key, Path value) noexcept
 {
   if (value == nullptr || StringIsEmpty(value.c_str()))
     Set(key, _T(""));
