@@ -17,12 +17,6 @@
 #include "ui/canvas/opengl/Scope.hpp"
 #endif
 
-int
-ChartRenderer::Axis::ToScreen(double value) const noexcept
-{
-  return int((value - min) * scale);
-}
-
 ChartRenderer::ChartRenderer(const ChartLook &_look, Canvas &the_canvas,
                              const PixelRect &the_rc,
                              [[maybe_unused]] const bool has_padding) noexcept
@@ -199,14 +193,13 @@ ChartRenderer::ScaleXFromValue(const double value) noexcept
 }
 
 void
-ChartRenderer::DrawLabel(const TCHAR *text,
-                         const double xv, const double yv) noexcept
+ChartRenderer::DrawLabel(DoublePoint2D v, const TCHAR *text) noexcept
 {
   canvas.Select(look.label_font);
   canvas.SetBackgroundTransparent();
 
   auto tsize = canvas.CalcTextSize(text);
-  auto pt = ToScreen(xv, yv);
+  auto pt = ToScreen(v);
   canvas.SelectNullPen();
   {
 #ifdef ENABLE_OPENGL
@@ -245,12 +238,9 @@ ChartRenderer::DrawTrend(const LeastSquares &lsdata,
   if (x.unscaled || y.unscaled)
     return;
 
-  auto xmin = x.min;
-  auto xmax = x.max;
-  auto ymin = lsdata.GetYAt(x.min);
-  auto ymax = lsdata.GetYAt(x.max);
-
-  DrawLine(xmin, ymin, xmax, ymax, look.GetPen(style));
+  DrawLine({x.min, lsdata.GetYAt(x.min)},
+           {x.max, lsdata.GetYAt(x.max)},
+           look.GetPen(style));
 }
 
 void
@@ -263,17 +253,13 @@ ChartRenderer::DrawTrendN(const LeastSquares &lsdata,
   if (x.unscaled || y.unscaled)
     return;
 
-  double xmin = 0.5;
-  double xmax = lsdata.GetCount() + 0.5;
-  double ymin = lsdata.GetYAtMinX();
-  double ymax = lsdata.GetYAtMaxX();
-
-  DrawLine(xmin, ymin, xmax, ymax, look.GetPen(style));
+  DrawLine({0.5, lsdata.GetYAtMinX()},
+           {lsdata.GetCount() + 0.5, lsdata.GetYAtMaxX()},
+           look.GetPen(style));
 }
 
 void
-ChartRenderer::DrawLine(const double xmin, const double ymin,
-                        const double xmax, const double ymax,
+ChartRenderer::DrawLine(DoublePoint2D min, DoublePoint2D max,
                         const Pen &pen) noexcept
 {
   if (x.unscaled || y.unscaled)
@@ -281,18 +267,17 @@ ChartRenderer::DrawLine(const double xmin, const double ymin,
 
   assert(pen.IsDefined());
   canvas.Select(pen);
-  canvas.DrawLine(ToScreen(xmin, ymin), ToScreen(xmax, ymax));
+  canvas.DrawLine(ToScreen(min), ToScreen(max));
 }
 
 void 
-ChartRenderer::DrawFilledLine(const double xmin, const double ymin,
-                              const double xmax, const double ymax,
+ChartRenderer::DrawFilledLine(DoublePoint2D min, DoublePoint2D max,
                               const Brush &brush) noexcept
 {
   BulkPixelPoint line[4];
 
-  line[0] = ToScreen(xmin, ymin);
-  line[1] = ToScreen(xmax, ymax);
+  line[0] = ToScreen(min);
+  line[1] = ToScreen(max);
 
   line[2].x = line[1].x;
   line[2].y = ScreenY(0);
@@ -305,11 +290,10 @@ ChartRenderer::DrawFilledLine(const double xmin, const double ymin,
 }
 
 void
-ChartRenderer::DrawLine(const double xmin, const double ymin,
-                        const double xmax, const double ymax,
+ChartRenderer::DrawLine(DoublePoint2D min, DoublePoint2D max,
                         ChartLook::Style style) noexcept
 {
-  DrawLine(xmin, ymin, xmax, ymax, look.GetPen(style));
+  DrawLine(min, max, look.GetPen(style));
 }
 
 void
@@ -342,10 +326,10 @@ PrepareLineGraph(BulkPixelPoint *p, std::span<const T> src,
 {
   if (swap) {
     for (const auto &i : src)
-      *p++ = chart.ToScreen(i.y, i.x);
+      *p++ = chart.ToScreen({i.y, i.x});
   } else {
     for (const auto &i : src)
-      *p++ = chart.ToScreen(i.x, i.y);
+      *p++ = chart.ToScreen(i);
   }
 
   return p;
@@ -606,18 +590,6 @@ ChartRenderer::DrawYGrid(double tic_step, double unit_step,
   }
 }
 
-int
-ChartRenderer::ScreenX(double _x) const noexcept
-{
-  return rc_chart.left + x.ToScreen(_x);
-}
-
-int
-ChartRenderer::ScreenY(double _y) const noexcept
-{
-  return rc_chart.bottom - y.ToScreen(_y);
-}
-
 void
 ChartRenderer::DrawFilledY(std::span<const DoublePoint2D> vals,
                            const Brush &brush, const Pen *pen) noexcept
@@ -644,10 +616,10 @@ ChartRenderer::DrawFilledY(std::span<const DoublePoint2D> vals,
 }
 
 void
-ChartRenderer::DrawDot(const double x, const double y,
+ChartRenderer::DrawDot(const DoublePoint2D _p,
                        const unsigned _width) noexcept
 {
-  auto p = ToScreen(x, y);
+  auto p = ToScreen(_p);
 
   const int width = _width;
   const BulkPixelPoint line[4] = {
@@ -661,13 +633,12 @@ ChartRenderer::DrawDot(const double x, const double y,
 }
 
 void
-ChartRenderer::DrawBlankRectangle(double x_min, double y_min,
-                                  double x_max, double y_max) noexcept
+ChartRenderer::DrawBlankRectangle(DoublePoint2D min, DoublePoint2D max) noexcept
 {
   if (x.unscaled || y.unscaled)
     return;
   canvas.Select(look.blank_brush);
-  canvas.DrawRectangle({ScreenX(x_min), ScreenY(y_min), ScreenX(x_max), ScreenY(y_max)});
+  canvas.DrawRectangle({ToScreen(min), ToScreen(max)});
 }
 
 void
@@ -679,8 +650,8 @@ ChartRenderer::DrawImpulseGraph(const XYDataStore &lsdata,
 
   canvas.Select(pen);
   for (const auto &i : slots) {
-    auto pt_base = ToScreen(i.x, y.min);
-    auto pt_top = ToScreen(i.x, i.y);
+    auto pt_base = ToScreen({i.x, y.min});
+    auto pt_top = ToScreen(i);
     canvas.DrawLine(pt_base, pt_top);
   }
 }
@@ -700,8 +671,8 @@ ChartRenderer::DrawWeightBarGraph(const XYDataStore &lsdata) noexcept
   canvas.SelectNullPen();
 
   for (const auto &i : slots) {
-    auto pt_base = ToScreen(i.x, y.min);
-    auto pt_top = ToScreen(i.x+i.weight, i.y);
+    auto pt_base = ToScreen({i.x, y.min});
+    auto pt_top = ToScreen({i.x+i.weight, i.y});
     canvas.DrawRectangle({pt_base.x, pt_base.y, pt_top.x, pt_top.y});
   }
 }
