@@ -3,15 +3,15 @@
 // author: Max Kellermann <mk@cm4all.com>
 
 #include "Error.hxx"
-#include "util/RuntimeError.hxx"
+#include "lib/fmt/RuntimeError.hxx"
 
 #include <ares.h>
 
 namespace Cares {
 
 Error::Error(int _code, const char *msg) noexcept
-	:std::runtime_error(FormatRuntimeError("%s: %s",
-					       msg, ares_strerror(_code))),
+	:std::runtime_error(FmtRuntimeError("{}: {}",
+					    msg, ares_strerror(_code))),
 	 code(_code) {}
 
 } // namespace Cares
