@@ -2,9 +2,10 @@
 // Copyright The XCSoar Project
 
 #include "FileMapping.hpp"
+#include "lib/fmt/PathFormatter.hpp"
+#include "lib/fmt/RuntimeError.hxx"
+#include "lib/fmt/SystemError.hxx"
 #include "system/Path.hpp"
-#include "system/Error.hxx"
-#include "util/RuntimeError.hxx"
 
 #ifdef HAVE_POSIX
 #include "UniqueFileDescriptor.hxx"
@@ -13,9 +14,9 @@
 #include <sys/mman.h>
 #include <sys/stat.h>
 #else
-#include "system/ConvertPathName.hpp"
-
 #include <fileapi.h>
+#include <handleapi.h> // for INVALID_HANDLE_VALUE
+#include <winbase.h> // for CreateFileMapping(), UnmapViewOfFile()
 #endif
 
 FileMapping::FileMapping(Path path)
@@ -25,42 +26,40 @@ FileMapping::FileMapping(Path path)
 
   struct stat st;
   if (fstat(fd.Get(), &st) < 0)
-    throw FormatErrno("Failed to stat %s", path.c_str());
+    throw FmtErrno("Failed to stat {}", path);
 
   /* mapping empty files can't be useful, let's make this a failure */
   if (st.st_size <= 0)
-    throw FormatRuntimeError("File empty: %s", path.c_str());
+    throw FmtRuntimeError("File empty: {}", path);
 
   /* file is too large */
   if (st.st_size > 1024 * 1024 * 1024)
-    throw FormatRuntimeError("File too large: %s", path.c_str());
+    throw FmtRuntimeError("File too large: {}", path);
 
   const std::size_t size = (std::size_t)st.st_size;
 
   void *data = mmap(nullptr, size, PROT_READ, MAP_SHARED, fd.Get(), 0);
   if (data == (void *)-1)
-    throw FormatErrno("Failed to map %s", path.c_str());
+    throw FmtErrno("Failed to map {}", path);
 
   madvise(data, size, MADV_WILLNEED);
 #else /* !HAVE_POSIX */
   hFile = ::CreateFile(path.c_str(), GENERIC_READ, FILE_SHARE_READ,
                        nullptr, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, nullptr);
   if (hFile == INVALID_HANDLE_VALUE) [[unlikely]]
-    throw FormatLastError("Failed to open %s",
-                          (const char *)NarrowPathName(path));
+    throw FmtLastError("Failed to open {}", path);
 
   BY_HANDLE_FILE_INFORMATION fi;
   if (!::GetFileInformationByHandle(hFile, &fi)) {
     const auto e = GetLastError();
     ::CloseHandle(hFile);
-    throw FormatLastError(e, "Failed to open %s",
-                          (const char *)NarrowPathName(path));
+    throw FmtLastError(e, "Failed to open {}", path);
   }
 
   if (fi.nFileSizeHigh > 0 ||
       fi.nFileSizeLow > 1024 * 1024 * 1024) {
     ::CloseHandle(hFile);
-    throw FormatRuntimeError("File too large: %s", path.c_str());
+    throw FmtRuntimeError("File too large: {}", path);
   }
 
   const std::size_t size = (std::size_t)fi.nFileSizeLow;
@@ -71,8 +70,7 @@ FileMapping::FileMapping(Path path)
   if (hMapping == nullptr) [[unlikely]] {
     const auto e = GetLastError();
     ::CloseHandle(hFile);
-    throw FormatLastError(e, "Failed to map %s",
-                          (const char *)NarrowPathName(path));
+    throw FmtLastError(e, "Failed to map {}", path);
   }
 
   void *data = ::MapViewOfFile(hMapping, FILE_MAP_READ, 0, 0, size);
@@ -80,8 +78,7 @@ FileMapping::FileMapping(Path path)
     const auto e = GetLastError();
     ::CloseHandle(hMapping);
     ::CloseHandle(hFile);
-    throw FormatLastError(e, "Failed to map %s",
-                          (const char *)NarrowPathName(path));
+    throw FmtLastError(e, "Failed to map {}", path);
   }
 #endif /* !HAVE_POSIX */
 
